==> aws-mock-1.2.0.tgz: package/src/integration-test/java/com/tlswe/awsmock/ec2/Ec2EndpointTest.java <==
/**
 * File name: Ec2EndpointTest.java Author: Willard Wang Create date: Aug 15,
 * 2013
 */
package com.tlswe.awsmock.ec2;

import java.util.List;
import java.util.Random;

import org.junit.Assert;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.amazonaws.services.ec2.model.Instance;
import com.amazonaws.services.ec2.model.InstanceStateChange;
import com.tlswe.awsmock.ec2.model.AbstractMockEc2Instance;

/**
 * This test class covers some sequential test cases to mock ec2 instances in aws-mock (run->stop->start-terminate,
 * etc), along with a case that tests running hundreds of instances.
 *
 * @author Willard Wang
 * @author xma
 */
public class Ec2EndpointTest extends BaseTest {

    /**
     * 2 minutes timeout.
     */
    private static final int TIMEOUT_LEVEL1 = 120000;

    /**
     * 4 minutes timeout.
     */
    private static final int TIMEOUT_LEVEL2 = 240000;

    /**
     * 10 seconds in millisecond.
     */
    private static final int TEN_SECONDS = 10000;

    /**
     * Log writer for this class.
     */
    private static Logger log = LoggerFactory.getLogger(Ec2EndpointTest.class);

    /**
     * Test one instance by run->stop.
     */
    @Test(timeout = TIMEOUT_LEVEL1)
    public final void sequenceRunStopTest() {
        log.info("Start simple run -> stop test");

        // run
        List<Instance> instances = runInstances(
                AbstractMockEc2Instance.InstanceType.M1_SMALL, 1, 1);
        Assert.assertTrue("fail to start instances", instances.size() == 1);

        instances = describeInstances(instances);
        Assert.assertTrue("fail to describe instances", instances.size() == 1);
        Assert.assertEquals("pending", instances.get(0).getState().getName());

        // wait for running
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.RUNNING);

        // stop
        List<InstanceStateChange> stateChanges = stopInstances(instances);
        Assert.assertTrue("fail to stop instances", stateChanges.size() == 1);
        Assert.assertEquals("stopping", stateChanges.get(0).getCurrentState()
                .getName());

        // wait for stopped
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.STOPPED);
    }

    /**
     * Test one instance by run->stop->start->terminate.
     */
    @Test(timeout = TIMEOUT_LEVEL2)
    public final void sequenceRunStopStartTerminateTest() {
        log.info("Start simple run->stop->start->terminate test");
        // run
        List<Instance> instances = runInstances(
                AbstractMockEc2Instance.InstanceType.M1_SMALL, 1, 1);
        Assert.assertTrue("fail to start instances", instances.size() == 1);

        // wait for running
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.RUNNING);

        // stop
        List<InstanceStateChange> stateChanges = stopInstances(instances);
        Assert.assertTrue("fail to stop instances", stateChanges.size() == 1);

        // wait for stopped
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.STOPPED);

        // re-start
        stateChanges = startInstances(instances);
        Assert.assertTrue("fail to re-start instances",
                stateChanges.size() == 1);

        // wait for running
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.RUNNING);

        // terminate
        stateChanges = terminateInstances(instances);
        Assert.assertTrue("fail to terminate instances",
                stateChanges.size() == 1);

        // wait for terminated
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.TERMINATED);
    }

    /**
     * Test one instance by run->terminate->start. A terminated instance can not start.
     */
    @Test
    public final void sequenceRunTerminateStartTest() {
        log.info("Start simple run->terminate->start test");
        // run
        List<Instance> instances = runInstances(
                AbstractMockEc2Instance.InstanceType.M1_SMALL, 1, 1);
        Assert.assertTrue("fail to start instances", instances.size() == 1);

        // wait for running
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.RUNNING);

        // terminate
        List<InstanceStateChange> stateChanges = terminateInstances(instances);
        Assert.assertTrue("fail to terminate instances",
                stateChanges.size() == 1);

        // wait for terminated
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.TERMINATED);

        // start, instance's state should remain terminated.
        stateChanges = startInstances(instances);
        Assert.assertTrue("fail to call start instances",
                stateChanges.size() == 1);

        // wait 10 seconds
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.RUNNING, TEN_SECONDS);

        instances = describeInstances(instances);
        Assert.assertTrue("number of instances should be 1",
                instances.size() == 1);
        Assert.assertTrue(
                "instance's state should be terminated",
                instances
                        .get(0)
                        .getState()
                        .getName()
                        .equals(AbstractMockEc2Instance.InstanceState.TERMINATED
                                .getName()));
    }

    /**
     * Test starting thousands of instances.
     */
    @Test
    public final void hundredsStartTest() {
        log.info("Start hundreds of instances test");

        final int startCount = 100;
        final int maxRandomCount = 200;
        // random 100 to 300 instances
        int count = startCount + new Random().nextInt(maxRandomCount);
        count = 500;
        for (int j = 1; j < 2; j++) {
        // run
            List<Instance> instances = runInstances(
                    AbstractMockEc2Instance.InstanceType.M1_SMALL, count, count);
            Assert.assertTrue("fail to start instances", instances.size() == count);
    
            // wait for running
            for (Instance i : instances) {
                waitForState(i.getInstanceId(),
                        AbstractMockEc2Instance.InstanceState.RUNNING);
            }
            
           
            // wait for running
            /* for (Instance i : instances) {
                waitForState(i.getInstanceId(),
                        AbstractMockEc2Instance.InstanceState.TERMINATED);
            }*/
   
         //   log.info("Created : " + 5000);
        }
    }

    /**
     * Test describing instances with states filter.
     */
    @Test(timeout = TIMEOUT_LEVEL2)
    public final void describeInstancesAllTest() {
        log.info("Start describing instances with states filter test");

        List<Instance> instances = describeInstances();
        if(instances != null)
        {
	        log.info("Count :" + instances.size());
	        for(Instance instance : instances){
	            log.info(instance.getInstanceId());
	        }
        }
        else
        {
        	log.info("Count :" + 0);
        }
    }
    /**
     * Test describing instances with states filter.
     */
    @Test(timeout = TIMEOUT_LEVEL2)
    public final void describeInstancesWithStatesFilterTest() {
        log.info("Start describing instances with states filter test");

        final int totalCount = 5;
        final int nonTerminatedCount = 3;
        final int terminateFromIndex = 1;
        final int terminateToIndex = 3;
        // run
        List<Instance> instances = runInstances(
                AbstractMockEc2Instance.InstanceType.M1_SMALL, totalCount, totalCount);
        Assert.assertTrue("fail to start instances", instances.size() == totalCount);

        // wait for running
        for (Instance i : instances) {
            waitForState(i.getInstanceId(),
                    AbstractMockEc2Instance.InstanceState.RUNNING);
        }

        // stop the first instance
        List<InstanceStateChange> stateChanges = stopInstances(instances.subList(0, 1));
        Assert.assertTrue("fail to stop instances", stateChanges.size() == 1);

        // wait for stopped
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.STOPPED);

        // terminate the second and third instance
        stateChanges = terminateInstances(instances.subList(terminateFromIndex, terminateToIndex));
        Assert.assertTrue("fail to terminate instances", stateChanges.size() == 2);

        // wait for terminated
        waitForState(instances.get(1).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.TERMINATED);
        waitForState(instances.get(2).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.TERMINATED);

        // get non terminated instances
        instances = describeNonTerminatedInstances(instances);

        Assert.assertTrue("number of non terminated instances should be 3",
                instances.size() == nonTerminatedCount);
    }
}

==> aws-mock-1.3.0.tgz: package/src/integration-test/java/com/tlswe/awsmock/ec2/Ec2EndpointTest.java <==
/**
 * File name: Ec2EndpointTest.java Author: Willard Wang Create date: Aug 15,
 * 2013
 */
package com.tlswe.awsmock.ec2;

import java.util.List;
import java.util.Random;

import org.junit.AfterClass;
import org.junit.Assert;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.amazonaws.services.ec2.model.Image;
import com.amazonaws.services.ec2.model.Instance;
import com.amazonaws.services.ec2.model.InstanceStateChange;
import com.tlswe.awsmock.ec2.model.AbstractMockEc2Instance;

/**
 * This test class covers some sequential test cases to mock ec2 instances in aws-mock (run->stop->start-terminate,
 * etc), along with a case that tests running hundreds of instances.
 *
 * @author Willard Wang
 * @author xma
 */
public class Ec2EndpointTest extends BaseTest {

    /**
     * 2 minutes timeout.
     */
    private static final int TIMEOUT_LEVEL1 = 120000;

    /**
     * 4 minutes timeout.
     */
    private static final int TIMEOUT_LEVEL2 = 240000;

    /**
     * 10 seconds in millisecond.
     */
    private static final int TEN_SECONDS = 10000;

    /**
     * Log writer for this class.
     */
    private static Logger log = LoggerFactory.getLogger(Ec2EndpointTest.class);

    private static Ec2EndpointTest context = null;

    /**
     * Test one instance by run->stop.
     */
    @Test(timeout = TIMEOUT_LEVEL1)
    public final void sequenceRunStopTest() {

	context = this;

        log.info("Start simple run -> stop test");

        // run
        List<Instance> instances = runInstances(
                AbstractMockEc2Instance.InstanceType.M1_SMALL, 1, 1);
        Assert.assertTrue("fail to start instances", instances.size() == 1);

        instances = describeInstances(instances);
        Assert.assertTrue("fail to describe instances", instances.size() == 1);
        Assert.assertEquals("pending", instances.get(0).getState().getName());

        // wait for running
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.RUNNING);

        // stop
        List<InstanceStateChange> stateChanges = stopInstances(instances);
        Assert.assertTrue("fail to stop instances", stateChanges.size() == 1);
        Assert.assertEquals("stopping", stateChanges.get(0).getCurrentState()
                .getName());

        // wait for stopped
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.STOPPED);
    }

    /**
     * Test one instance by run->stop->start->terminate.
     */
    @Test(timeout = TIMEOUT_LEVEL2)
    public final void sequenceRunStopStartTerminateTest() {
        log.info("Start simple run->stop->start->terminate test");
        // run
        List<Instance> instances = runInstances(
                AbstractMockEc2Instance.InstanceType.M1_SMALL, 1, 1);
        Assert.assertTrue("fail to start instances", instances.size() == 1);

        // wait for running
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.RUNNING);

        // stop
        List<InstanceStateChange> stateChanges = stopInstances(instances);
        Assert.assertTrue("fail to stop instances", stateChanges.size() == 1);

        // wait for stopped
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.STOPPED);

        // re-start
        stateChanges = startInstances(instances);
        Assert.assertTrue("fail to re-start instances",
                stateChanges.size() == 1);

        // wait for running
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.RUNNING);

        // terminate
        stateChanges = terminateInstances(instances);
        Assert.assertTrue("fail to terminate instances",
                stateChanges.size() == 1);

        // wait for terminated
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.TERMINATED);
    }

    /**
     * Test one instance by run->terminate->start. A terminated instance can not start.
     */
    @Test
    public final void sequenceRunTerminateStartTest() {
        log.info("Start simple run->terminate->start test");
        // run
        List<Instance> instances = runInstances(
                AbstractMockEc2Instance.InstanceType.M1_SMALL, 1, 1);
        Assert.assertTrue("fail to start instances", instances.size() == 1);

        // wait for running
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.RUNNING);

        // terminate
        List<InstanceStateChange> stateChanges = terminateInstances(instances);
        Assert.assertTrue("fail to terminate instances",
                stateChanges.size() == 1);

        // Commenting  the test as we cannot recover the terminated instances
/*        // wait for terminated
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.TERMINATED);

        // start, instance's state should remain terminated.
        stateChanges = startInstances(instances);
        Assert.assertTrue("fail to call start instances",
                stateChanges.size() == 1);

        // wait 10 seconds
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.RUNNING, TEN_SECONDS);

        instances = describeInstances(instances);
        Assert.assertTrue("number of instances should be 1",
                instances.size() == 1);
        Assert.assertTrue(
                "instance's state should be terminated",
                instances
                        .get(0)
                        .getState()
                        .getName()
                        .equals(AbstractMockEc2Instance.InstanceState.TERMINATED
                                .getName()));*/
    }

    /**
     * Test starting thousands of instances.
     */
    @Test
    public final void hundredsStartTest() {
        log.info("Start hundreds of instances test");

        final int startCount = 100;
        final int maxRandomCount = 200;
        // random 100 to 300 instances
        int count = startCount + new Random().nextInt(maxRandomCount);
        count = 500;
        for (int j = 1; j < 2; j++) {
        // run
            List<Instance> instances = runInstances(
                    AbstractMockEc2Instance.InstanceType.M1_SMALL, count, count);
            Assert.assertTrue("fail to start instances", instances.size() == count);
    
            // wait for running
            for (Instance i : instances) {
                waitForState(i.getInstanceId(),
                        AbstractMockEc2Instance.InstanceState.RUNNING);
            }
            
           
            // terminate to avoid memory leak
            terminateInstances(instances);
        }

        
    }

    /**
     * Test describing instances with states filter.
     */
    @Test(timeout = TIMEOUT_LEVEL2)
    public final void describeInstancesAllTest() {
        log.info("Start describing instances with states filter test");

        List<Instance> instances = describeInstances();
        if(instances != null)
        {
	        log.info("Count :" + instances.size());
	        for(Instance instance : instances){
	            log.info(instance.getInstanceId());
	        }
        }
        else
        {
        	log.info("Count :" + 0);
        }
    }
    
    /**
     * Test describing instances with states filter.
     */
    @Test(timeout = TIMEOUT_LEVEL2)
    public final void describeImagesAllTest() {
        log.info("Start describing Images with states filter test");

        List<Image> instances = describeImages();
        if(instances != null)
        {
           for (Image i : instances) {
             log.info(i.getImageId());
           }
        }
        else
        {
        	log.info("Count :" + 0);
        }
    }


    /**
     * Test describing instances with states filter.
     */
    @Test(timeout = TIMEOUT_LEVEL2)
    public final void describeInstancesWithStatesFilterTest() {
        log.info("Start describing instances with states filter test");

        final int totalCount = 5;
        final int nonTerminatedCount = 3;
        final int terminateFromIndex = 1;
        final int terminateToIndex = 3;
        // run
        List<Instance> instances = runInstances(
                AbstractMockEc2Instance.InstanceType.M1_SMALL, totalCount, totalCount);
        Assert.assertTrue("fail to start instances", instances.size() == totalCount);

        // wait for running
        for (Instance i : instances) {
            waitForState(i.getInstanceId(),
                    AbstractMockEc2Instance.InstanceState.RUNNING);
        }

        // stop the first instance
        List<InstanceStateChange> stateChanges = stopInstances(instances.subList(0, 1));
        Assert.assertTrue("fail to stop instances", stateChanges.size() == 1);

        // wait for stopped
        waitForState(instances.get(0).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.STOPPED);

        // terminate the second and third instance
        stateChanges = terminateInstances(instances.subList(terminateFromIndex, terminateToIndex));
        Assert.assertTrue("fail to terminate instances", stateChanges.size() == 2);

        // wait for terminated
        waitForState(instances.get(1).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.TERMINATED);
        waitForState(instances.get(2).getInstanceId(),
                AbstractMockEc2Instance.InstanceState.TERMINATED);

        // get non terminated instances
        instances = describeNonTerminatedInstances(instances);

        Assert.assertTrue("number of non terminated instances should be 3",
                instances.size() == nonTerminatedCount);
    }

    @AfterClass
    public static void cleanUp(){
	List<Instance>  instances = context.describeInstances();
        instances = context.describeNonTerminatedInstances(instances);
        context.terminateInstances(instances);

        for (Instance i : instances) {
            context.waitForState(i.getInstanceId(),
                    AbstractMockEc2Instance.InstanceState.TERMINATED);
        }
    }
}
